import collections
import logging
from typing import Tuple, List, Optional

from qdrant_client import QdrantClient
from qdrant_client.conversions.common_types import PointId, Record

from bot_station.data.docs.mapper.document_mapper import SOURCE_LINK_KEY
from bot_station.domain.docs.model.document import Document


class QdrantDocsIterator(collections.abc.Iterator):
    qdrant_cli: QdrantClient
    collection_name: str
    last_point_id: PointId | None
    iteration_started: bool

    def __init__(self,
                 qdrant_cli: QdrantClient,
                 collection_name: str
                 ):
        self.qdrant_cli = qdrant_cli
        self.collection_name = collection_name
        self.last_point_id = None
        self.iteration_started = False

    def __next__(self):
        if self.iteration_started and self.last_point_id is None:
            raise StopIteration()
        self.iteration_started = True

        try:
            result: Tuple[List[Record], Optional[PointId]] = \
                self.qdrant_cli.scroll(collection_name=self.collection_name,
                                       limit=1,
                                       offset=self.last_point_id,
                                       with_vectors=False)
            record: Record = result[0][0]
            self.last_point_id = result[1]

            data = record.payload["document"]
            record.payload.pop("document")
            metadata = record.payload
            source_link = metadata[SOURCE_LINK_KEY]
            return Document(id=record.id, data=data, source_link=source_link, metadata=metadata)
        except Exception as e:
            logging.error(f"Iteration error: {e}")
            raise StopIteration()


class QdrantDocsIterable(collections.abc.Iterable):
    qdrant_cli: QdrantClient
    collection_name: str

    def __init__(self,
                 qdrant_cli: QdrantClient,
                 collection_name: str
                 ):
        self.qdrant_cli = qdrant_cli
        self.collection_name = collection_name

    def __iter__(self):
        return QdrantDocsIterator(qdrant_cli=self.qdrant_cli, collection_name=self.collection_name)



import logging
from typing import List

from bot_station.domain.bot.bot import Bot
from bot_station.domain.bot.chat_message_storage import ChatMessageStorage
from bot_station.domain.bot.model.bot_meta_info import BotMetaInfo
from bot_station.domain.bot.model.lm_call_result import CallResult
from bot_station.domain.bot.model.lm_chat_message import LMBotMessage, LmChatMessage
from bot_station.domain.bot.model.lm_chat_message import LMUserMessage
from bot_station.domain.docs.docs_library import DocsLibrary
from bot_station.domain.docs.model.document import Document
from bot_station.domain.docs.model.documents_search_result import DocumentsSearchResult
from bot_station.domain.llm.llm import LLM


class BotImpl(Bot):
    docs_library: DocsLibrary
    llm: LLM
    message_storage: ChatMessageStorage
    meta: BotMetaInfo

    """
    TODO: перенести prompt и настройки LLM в конфиг или наверх
    """
    __message_history_title = "Переписка с пользователем: "
    __relevant_docs_title = "Для ответа используй следующую информацию: "
    __user_question_title = "Сообщение пользователя: "

    def __init__(
            self,
            message_storage: ChatMessageStorage,
            docs_library: DocsLibrary,
            llm: LLM,
            meta: BotMetaInfo
    ):
        self.message_storage = message_storage
        self.docs_library = docs_library
        self.llm = llm
        self.meta = meta
        self.__is_loaded = False

    async def call(self, question: LMUserMessage) -> CallResult:
        logging.debug(f"call({question})")

        prompt_with_question = self.meta.prompt_intro + "\n"

        # 1. Add previous messages to prompt
        if self.meta.add_messages_history_to_prompt:
            message_history: List[LmChatMessage] = \
                await self.message_storage.get_history(chat_id=question.chat_id, limit=10)
            if len(message_history) >= 2:
                prompt_with_question = prompt_with_question + f"\n{self.__message_history_title}\n"
                for m in message_history:
                    prompt_with_question = prompt_with_question + "- " + m.text + "\n"

        # 2. Add context to prompt
        relevant_docs: List[Document] = []
        if self.meta.add_external_context_to_prompt:
            await self.docs_library.load()
            search_docs_result: DocumentsSearchResult = await self.docs_library.get_relevant_docs(
                query=question.text,
                min_score=self.meta.min_extract_relevant_docs_score,
                limit=self.meta.limit_extract_relevant_docs,
            )
            relevant_docs: List[Document] = [search_docs_result.docs[key] for key in search_docs_result.docs]
            await self.docs_library.close()
            if len(relevant_docs) > 0:
                prompt_with_question = (
                        prompt_with_question
                        + f"\n{self.__relevant_docs_title}\n"
                )
                for d in relevant_docs:
                    prompt_with_question = prompt_with_question + f"\n{d.data}"

        prompt_with_question = (prompt_with_question + f"\n{self.__user_question_title}" + question.text)

        logging.debug(f"Send message to LLM: {prompt_with_question}")
        response = await self.llm.call(prompt_with_question)
        logging.debug(f"Response: {response}")

        answer = LMBotMessage(text=response, chat_id=question.chat_id)
        await self.message_storage.add_user_message(chat_id=question.chat_id, message=question)
        await self.message_storage.add_bot_message(chat_id=question.chat_id, message=answer)

        return CallResult(answer=answer, relevant_docs=relevant_docs)



from dataclasses import dataclass, field
from typing import TypeAlias

DocId: TypeAlias = str


@dataclass
class Document:
    id: DocId = field()
    data: str = field()
    source_link: str | None = field(default=None)
    metadata: dict | None = field(default_factory=dict)



from dataclasses import dataclass
from typing import TypeAlias

from bot_station.domain.docs.model.document import Document

RelevanceScore: TypeAlias = float


@dataclass
class DocumentsSearchResult:
    docs: dict[RelevanceScore, Document]



import logging
from abc import abstractmethod, ABC
from typing import List

from bot_station.domain.bot.bot import Bot
from bot_station.domain.bot.bot_factory import BotFactory
from bot_station.domain.bot.model.bot_meta_info import BotMetaInfo
from bot_station.domain.bot_station.bot_registry import BotRegistry


class BotStation(ABC):

    @abstractmethod
    async def create(self, config: BotMetaInfo):
        pass

    @abstractmethod
    async def get_bot(self, bot_id: str) -> Bot | None:
        pass

    @abstractmethod
    async def get_bots_list(self) -> List[BotMetaInfo]:
        pass

    @abstractmethod
    async def delete(self, bot_id: str) -> bool:
        pass

    @abstractmethod
    async def update(self, info: BotMetaInfo):
        pass


class BotStationImpl(BotStation):
    bot_registry: BotRegistry
    bot_factory: BotFactory

    __in_memory_bots: dict[str, Bot] = {}

    def __init__(
            self,
            bot_registry: BotRegistry,
            bot_factory: BotFactory,
    ):
        self.bot_registry = bot_registry
        self.bot_factory = bot_factory

    async def create(self, bot_info: BotMetaInfo):
        logging.debug(f"create {bot_info}")
        bot_with_same_id = await self.bot_registry.get(bot_id=bot_info.id)
        if bot_with_same_id is None:
            meta_info = await self.bot_registry.create(bot_info)
            return meta_info
        else:
            raise Exception(f"Bot with id '{bot_info.id}' already exists!")

    async def get_bot(self, bot_id: str) -> Bot | None:
        logging.debug(f"Get {bot_id})")
        if bot_id is None:
            raise Exception("Bot id is None!")
        bot = self.__in_memory_bots.get(bot_id, None)
        if bot is not None:
            return bot

        meta = await self.bot_registry.get(bot_id)
        if meta is None:
            logging.warning(f"No {bot_id} in registry!")
            return None
        else:
            bot = await self.bot_factory.create(meta=meta)
            await bot.docs_library.load()
            self.__in_memory_bots[bot_id] = bot
            return bot

    async def get_bots_list(self) -> List[BotMetaInfo]:
        logging.debug("get_bots_list")
        return await self.bot_registry.get_all()

    async def delete(self, bot_id: str) -> bool:
        logging.debug(f"delete {bot_id}")
        bot = await self.get_bot(bot_id=bot_id)
        if bot is not None:
            await bot.docs_library.load()
            await bot.docs_library.clear()
            await self.bot_registry.delete(bot_id=bot_id)
            self.__in_memory_bots.pop(bot_id, None)
            return True
        else:
            logging.warning(f"No {bot_id} in registry")
            return False

    async def update(self, info: BotMetaInfo):
        logging.debug(f"Update {info}")
        await self.bot_registry.update(info)
        # reload bot
        bot = self.__in_memory_bots.pop(info.id, None)
        if bot is not None:
            logging.debug(f"Close {bot.meta}")
            await bot.docs_library.close()



from sqlalchemy import Column, TIMESTAMP
from sqlalchemy.orm import DeclarativeBase

from bot_station.data.base.database.UUID import uuid_id_column


class BaseDBDto(DeclarativeBase):
    __abstract__ = True

    id = uuid_id_column()
    created_at = Column(TIMESTAMP, nullable=True)
    updated_at = Column(TIMESTAMP, nullable=True)

    def __repr__(self):
        return "<{0.__class__.__name__}(id={0.id!r})>".format(self)



from bot_station.data.bot.bot_factory_impl import BotFactoryImpl
from bot_station.data.bot.model.qdrant_config import QdrantConfig
from bot_station.data.bot.model.yandex_cloud_config import YandexCloudConfig
from bot_station.data.bot_station.bot_registry_impl import BotRegistryImpl
from bot_station.domain.bot.bot_factory import BotFactory
from bot_station.domain.bot_station.bot_registry import BotRegistry
from bot_station.domain.bot_station.bot_station import BotStation, BotStationImpl


class BotStationModule(object):
    overrides_bot_factory: BotFactory | None = None

    @staticmethod
    def provide_bot_factory(bot_factory: BotFactory):
        BotStationModule.overrides_bot_factory = bot_factory

    @staticmethod
    def create_bot_station(
            yandex_cloud_config: YandexCloudConfig,
            qdrant_config: QdrantConfig,
    ) -> BotStation:
        bot_registry: BotRegistry = BotRegistryImpl()
        bot_station: BotStation = BotStationImpl(
            bot_registry=bot_registry,
            bot_factory=BotStationModule.__get_bot_factory(yandex_cloud_config, qdrant_config),
        )
        return bot_station

    @staticmethod
    def __get_bot_factory(
            env_config: YandexCloudConfig,
            qdrant_config: QdrantConfig,
    ) -> BotFactory:
        if BotStationModule.overrides_bot_factory is not None:
            return BotStationModule.overrides_bot_factory
        else:
            factory = BotFactoryImpl()
            factory.yandex_cloud_config = env_config
            factory.qdrant_config = qdrant_config
            return factory



from pydantic import BaseModel, Field


class BotDto(BaseModel):
    id: str = Field(min_length=1, max_length=100)
    name: str = Field(min_length=0, max_length=50)
    description: str = Field(min_length=0, max_length=500)
    prompt_intro: str = Field(min_length=0, max_length=5000)
    add_external_context_to_prompt: bool = Field(True)
    add_messages_history_to_prompt: bool = Field(False)
    temperature: float = Field(0.6)



from dataclasses import dataclass

from bot_station.domain.base.const import default_prompt_intro


@dataclass
class BotMetaInfo:
    id: str
    name: str
    description: str
    prompt_intro: str = default_prompt_intro
    add_external_context_to_prompt: bool = True
    add_messages_history_to_prompt: bool = False
    temperature: float = 0.6
    min_extract_relevant_docs_score: float = 0.7,
    limit_extract_relevant_docs: int = 3



from typing import List

from sqlalchemy import create_engine, select, delete
from sqlalchemy.orm import Session

from bot_station.data.bot_station import db_path
from bot_station.data.bot_station.model.bot_info_dto import BotInfoDto
from bot_station.domain.bot_station.bot_registry import BotRegistry
from bot_station.domain.bot.model.bot_meta_info import BotMetaInfo


class BotRegistryImpl(BotRegistry):
    __engine = create_engine(db_path, echo=False)
    __storage = {}

    async def create(self, config: BotMetaInfo) -> BotMetaInfo:
        session = Session(self.__engine)
        dto = BotInfoDto(
            id=config.id,
            name=config.name,
            description=config.description,
            prompt_intro=config.prompt_intro,
            add_external_context_to_prompt=config.add_external_context_to_prompt,
            add_messages_history_to_prompt=config.add_messages_history_to_prompt,
            temperature=config.temperature,
        )
        session.add(dto)
        session.commit()
        return self.__map_from_dto(dto)

    async def get(self, bot_id: str) -> BotMetaInfo | None:
        session = Session(self.__engine)
        dto = self.__select_dto(bot_id=bot_id, session=session)
        if dto is None:
            return None
        else:
            return self.__map_from_dto(dto)

    async def get_all(self) -> List[BotMetaInfo]:
        session = Session(self.__engine)
        stmt = select(BotInfoDto)
        dtos = session.scalars(stmt).all()
        return list(map(lambda dto: self.__map_from_dto(dto), dtos))

    async def update(self, meta: BotMetaInfo):
        session = Session(self.__engine)
        dto = self.__select_dto(bot_id=meta.id, session=session)
        if dto is not None:
            dto.name = meta.name
            dto.description = meta.description
            dto.temperature = meta.temperature
            dto.prompt_intro = meta.prompt_intro
            dto.add_external_context_to_prompt = meta.add_external_context_to_prompt
            dto.add_messages_history_to_prompt = meta.add_messages_history_to_prompt

            session.commit()

    def __select_dto(self, bot_id: str, session: Session) -> BotInfoDto | None:
        stmt = select(BotInfoDto).where(BotInfoDto.id.is_(bot_id))
        return session.scalars(stmt).one_or_none()

    async def delete(self, bot_id: str):
        session = Session(self.__engine)
        sql = delete(BotInfoDto).where(BotInfoDto.id == bot_id)
        session.execute(sql)
        session.commit()

    @staticmethod
    def __map_from_dto(dto: BotInfoDto) -> BotMetaInfo:
        return BotMetaInfo(
            id=str(dto.id),
            name=dto.name,
            description=dto.description,
            prompt_intro=dto.prompt_intro,
            add_external_context_to_prompt=dto.add_external_context_to_prompt,
            add_messages_history_to_prompt=dto.add_messages_history_to_prompt,
            temperature=dto.temperature,
        )

    @staticmethod
    def __map_to_dto(info: BotMetaInfo) -> BotInfoDto:
        return BotInfoDto(
            id=info.id,
            name=info.name,
            description=info.description,
            prompt_intro=info.prompt_intro,
            add_external_context_to_prompt=info.add_external_context_to_prompt,
            add_messages_history_to_prompt=info.add_messages_history_to_prompt,
            temperature=info.temperature,
        )



from abc import ABC, abstractmethod

from bot_station.domain.bot.bot import Bot
from bot_station.domain.bot.model.bot_meta_info import BotMetaInfo


class BotFactory(ABC):

    @abstractmethod
    async def create(self, meta: BotMetaInfo) -> Bot:
        pass



import logging

from bot_station.data.bot.bot_impl import BotImpl
from bot_station.data.bot.chat_message_storage_impl import ChatMessageStorageImpl
from bot_station.data.bot.model.qdrant_config import QdrantConfig
from bot_station.data.bot.model.yandex_cloud_config import YandexCloudConfig
from bot_station.data.docs.qdrant_docs_library import QdrantDocsLibrary
from bot_station.data.llm.yandex_gpt_llm import YandexGPTLLM
from bot_station.domain.base.const import message_history_path
from bot_station.domain.bot.bot import Bot
from bot_station.domain.bot.bot_factory import BotFactory
from bot_station.domain.bot.model.bot_meta_info import BotMetaInfo
from bot_station.domain.docs.docs_library import DocsLibrary
from bot_station.domain.llm.llm import LLM


class BotFactoryImpl(BotFactory):
    """
    Дб выставлено или config или реализация до вызова create()
    """
    yandex_cloud_config: YandexCloudConfig
    qdrant_config: QdrantConfig

    docs_library: DocsLibrary
    llm: LLM

    def __init__(self):
        self.yandex_cloud_config = None
        self.qdrant_config = None
        self.docs_library = None
        self.llm = None

    async def create(self, meta: BotMetaInfo) -> Bot:
        logging.debug(f"Create {meta}")
        if self.docs_library is None:
            self.docs_library = QdrantDocsLibrary(
                collection_name=meta.id,
                qdrant_config=self.qdrant_config
            )
        if self.llm is None:
            self.llm = YandexGPTLLM(
                yandex_cloud_config=self.yandex_cloud_config,
                temperature=meta.temperature
            )
        bot = BotImpl(
            message_storage=ChatMessageStorageImpl(root_message_history_path=message_history_path),
            llm=self.llm,
            docs_library=self.docs_library,
            meta=meta
        )
        return bot



from sqlalchemy import create_engine, Engine

from bot_station.data.base.database.base_db_dto import BaseDBDto
from bot_station.data.bot_station.model.bot_info_dto import BotInfoDto
from bot_station.domain.base.const import databases_path
from bot_station.domain.base.utils import ensure_data_folder_existence

ensure_data_folder_existence()
db_path = f"sqlite:///{databases_path}/bot_station.db"

engine: Engine = create_engine(db_path, echo=False, echo_pool=False)
BaseDBDto.metadata.create_all(bind=engine)



from pathlib import Path

from bot_station.domain.base.const import (
    data_folder_path,
    databases_path,
    message_history_path,
)


def ensure_data_folder_existence():
    for path in [
        data_folder_path,
        databases_path,
        message_history_path,
    ]:
        path = Path(path)
        if not path.exists():
            path.mkdir(parents=True, exist_ok=True)



from dataclasses import dataclass

from bot_station.domain.docs.model.document import Document
from bot_station.domain.bot.model.lm_chat_message import LMBotMessage


@dataclass
class CallResult:
    answer: LMBotMessage
    relevant_docs: list[Document]



from dataclasses import dataclass

from pydantic import BaseModel, Field


@dataclass
class BotTrainDto(BaseModel):
    bot_id: str = Field(min_length=1, max_length=100)
    data: str = Field(min_length=0, max_length=10_000)
    source_link: str | None = Field(min_length=0, max_length=1000)
    metadata: dict[str, str] = Field(default_factory=dict)



import logging
from typing import List, Iterable

from qdrant_client import QdrantClient
from qdrant_client.fastembed_common import QueryResponse

from bot_station.data.bot.model.qdrant_config import QdrantConfig
from bot_station.data.docs.mapper.document_mapper import DocumentMapper, SOURCE_LINK_KEY
from bot_station.data.docs.qdrant_docs_iterator import QdrantDocsIterable
from bot_station.domain.docs.docs_library import DocsLibrary
from bot_station.domain.docs.model.document import Document, DocId
from bot_station.domain.docs.model.documents_search_result import RelevanceScore, DocumentsSearchResult


class QdrantDocsLibrary(DocsLibrary):
    qdrant_config: QdrantConfig
    collection_name: str

    qdrant_cli: QdrantClient

    __is_loaded: bool

    def __init__(
            self,
            collection_name: str,
            qdrant_config: QdrantConfig,
    ):
        logging.debug(f"Init {collection_name}")
        self.qdrant_config = qdrant_config
        self.collection_name = collection_name
        self.__is_loaded = False

    async def load(self):
        logging.debug("load()")
        if self.__is_loaded:
            logging.warning("Already loaded")
            return

        if self.qdrant_config.qdrant_url is not None:
            self.qdrant_cli = QdrantClient(url=self.qdrant_config.qdrant_url)
        elif self.qdrant_config.qdrant_db_path is not None:
            self.qdrant_cli = QdrantClient(path=self.qdrant_config.qdrant_db_path)
        else:
            raise AssertionError("qdrant_uri or qdrant_db_path not set")

        self.__ensure_quadrant_collection_created()
        self.__is_loaded = True

    async def create_document(
            self,
            data: str,
            source_link: str | None = None,
            metadata: dict = {},
    ) -> Document:
        if not self.__is_loaded:
            raise AssertionError("Calling add_document() for not loaded instance!")

        metadata[SOURCE_LINK_KEY] = source_link
        ids = self.qdrant_cli.add(
            collection_name=self.collection_name,
            documents=[data],
            metadata=[metadata],
        )
        return Document(
            id=ids[0],
            data=data,
            source_link=source_link,
            metadata=metadata,
        )

    async def delete_document(self, doc_id: DocId):
        self.qdrant_cli.delete(collection_name=self.collection_name, points_selector=[doc_id])

    async def get_all_docs(self) -> Iterable[Document]:
        return QdrantDocsIterable(qdrant_cli=self.qdrant_cli, collection_name=self.collection_name)

    async def get_relevant_docs(
            self,
            query: str,
            min_score: RelevanceScore = 0.8,
            limit: int = 10
    ) -> DocumentsSearchResult:
        response_docs: List[QueryResponse] = self.qdrant_cli.query(collection_name=self.collection_name,
                                                                   query_text=query,
                                                                   limit=limit)
        filtered_docs: List[QueryResponse] = filter(lambda d: d.score >= min_score, response_docs)
        docs: dict[RelevanceScore, Document] = {}
        for d in filtered_docs:
            docs[d.score] = DocumentMapper.from_qdrant_response(d)
        return DocumentsSearchResult(docs)

    async def close(self):
        if not self.__is_loaded:
            return
        try:
            self.qdrant_cli.close()
            self.__is_loaded = False
        except Exception as e:
            logging.error(e)

    async def clear(self):
        if not self.__is_loaded:
            raise AssertionError("Calling clear() for not loaded instance!")
        if self.qdrant_cli.collection_exists(collection_name=self.collection_name):
            self.qdrant_cli.delete_collection(collection_name=self.collection_name)

    def __ensure_quadrant_collection_created(self):
        if not self.qdrant_cli.collection_exists(collection_name=self.collection_name):
            self.qdrant_cli.create_collection(
                collection_name=self.collection_name,
                vectors_config=self.qdrant_cli.get_fastembed_vector_params(),
            )



default_prompt_intro = """
           Ты - ассистент, отвечающий на вопросы. Давай точные ответы или, если не знаешь ответ, уточни запрос.
            """

# TODO: обернуть это и пути в ConfigProvider и передавать через конструктор
data_folder_path = "./.data"
databases_path = data_folder_path + "/database"
message_history_path = data_folder_path + "/message_history"
chat_files_path = data_folder_path + "/chat_files"



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

with open('requirements.txt') as f:
    requirements = f.read().splitlines()

with open('version.txt') as f:
    version = f.read()


setuptools.setup(
    name="bot_station",
    version=version,
    author="Maxim Marashan",
    # author_email="ericjaychi@gmail.com",
    description="Bot Station SDK + Web App",
    long_description=long_description,
    long_description_content_type="text/markdown",
    # url="https://github.com/ericjaychi/sample-pypi-package",
    packages=setuptools.find_packages(),
    install_requires=requirements,
    classifiers=[
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.10',
)



from langchain_community.chat_models import ChatYandexGPT
from langchain_core.language_models import BaseChatModel
from langchain_core.tracers import langchain

from bot_station.data.bot.model.yandex_cloud_config import YandexCloudConfig
from bot_station.domain.llm.llm import LLM


class YandexGPTLLM(LLM):
    gpt: BaseChatModel

    def __init__(
            self,
            yandex_cloud_config: YandexCloudConfig,
            temperature: float = 0.6,
    ):
        langchain.debug = False
        self.gpt = ChatYandexGPT(
            api_key=yandex_cloud_config.api_key,
            folder_id=yandex_cloud_config.folder_id,
            temperature=temperature,
            model_name=yandex_cloud_config.model_name,
            verbose=True,
        )

    async def call(self, query: str) -> str:
        return self.gpt.invoke(query).content



import uuid

from sqlalchemy import String, Float, Boolean
from sqlalchemy.orm import Mapped, mapped_column

from bot_station.data.base.database.base_db_dto import BaseDBDto


class BotInfoDto(BaseDBDto):
    __tablename__ = "bot_meta_info"

    id: Mapped[str] = mapped_column("id", String(), primary_key=True, default=uuid.uuid4)
    name: Mapped[str] = mapped_column(String())
    description: Mapped[str] = mapped_column(String())
    temperature: Mapped[float] = mapped_column(Float())
    prompt_intro: Mapped[str] = mapped_column(String())
    add_external_context_to_prompt: Mapped[bool] = mapped_column(Boolean())
    add_messages_history_to_prompt: Mapped[bool] = mapped_column(Boolean())

    def __repr__(self) -> str:
        return f"Bot(id={self.id!r}, name={self.name!r}, temperature={self.temperature!r}, prompt={self.prompt_intro!r})"



from dataclasses import dataclass, field


@dataclass
class WebAppConfig:
    version: str = field(default="0.1.0")
    title: str = field(default="Bot Station API")
    debug: bool = field(default=True)
